@@ -16,28 +16,28 @@
 
 #include <KLocalizedString>
 
-#include <unistd.h>
 #include <errno.h>
-#include <signal.h>
-#include <termios.h>
 #include <fcntl.h>
+#include <signal.h>
 #include <sys/ioctl.h>
+#include <termios.h>
+#include <unistd.h>
 #if HAVE_SYS_FILIO_H
-# include <sys/filio.h>
+#include <sys/filio.h>
 #endif
 #if HAVE_SYS_TIME_H
-# include <sys/time.h>
+#include <sys/time.h>
 #endif
 
 #if defined(Q_OS_FREEBSD) || defined(Q_OS_MAC)
 // "the other end's output queue size" - kinda braindead, huh?
-# define PTY_BYTES_AVAILABLE TIOCOUTQ
+#define PTY_BYTES_AVAILABLE TIOCOUTQ
 #elif defined(TIOCINQ)
 // "our end's input queue size"
-# define PTY_BYTES_AVAILABLE TIOCINQ
+#define PTY_BYTES_AVAILABLE TIOCINQ
 #else
 // likewise. more generic ioctl (theoretically)
-# define PTY_BYTES_AVAILABLE FIONREAD
+#define PTY_BYTES_AVAILABLE FIONREAD
 #endif
 
 #define KMAXINT ((int)(~0U >> 1))
@@ -95,7 +95,7 @@ public:
         totalSize -= bytes;
         Q_ASSERT(totalSize >= 0);
 
-        forever {
+        for (;;) {
             int nbs = readSize();
 
             if (bytes < nbs) {
@@ -158,7 +158,7 @@ public:
         int index = 0;
         int start = head;
         QVector<QByteArray>::ConstIterator it = buffers.begin();
-        forever {
+        for (;;) {
             if (!maxLength) {
                 return index;
             }
@@ -167,8 +167,7 @@ public:
             }
             const QByteArray &buf = *it;
             ++it;
-            int len = qMin((it == buffers.end() ? tail : buf.size()) - start,
-                           maxLength);
+            int len = qMin((it == buffers.end() ? tail : buf.size()) - start, maxLength);
             const char *ptr = buf.data() + start;
             if (const char *rptr = (const char *)memchr(ptr, c, len)) {
                 return index + (rptr - ptr) + 1;
@@ -231,15 +230,23 @@ static void qt_ignore_sigpipe()
     }
 }
 
-#define NO_INTR(ret,func) do { ret = func; } while (ret < 0 && errno == EINTR)
+/* clang-format off */
+#define NO_INTR(ret, func) \
+    do { \
+        ret = func; \
+    } while (ret < 0 && errno == EINTR)
+/* clang-format on */
 
-struct KPtyDevicePrivate : public KPtyPrivate {
+class KPtyDevicePrivate : public KPtyPrivate
+{
     Q_DECLARE_PUBLIC(KPtyDevice)
-
-    KPtyDevicePrivate(KPty *parent) :
-        KPtyPrivate(parent),
-        emittedReadyRead(false), emittedBytesWritten(false),
-        readNotifier(nullptr), writeNotifier(nullptr)
+public:
+    KPtyDevicePrivate(KPty *parent)
+        : KPtyPrivate(parent)
+        , emittedReadyRead(false)
+        , emittedBytesWritten(false)
+        , readNotifier(nullptr)
+        , writeNotifier(nullptr)
     {
     }
 
@@ -263,7 +270,7 @@ bool KPtyDevicePrivate::_k_canRead()
     qint64 readBytes = 0;
 
     int available;
-    if (!::ioctl(q->masterFd(), PTY_BYTES_AVAILABLE, (char *) &available)) {
+    if (!::ioctl(q->masterFd(), PTY_BYTES_AVAILABLE, (char *)&available)) {
         char *ptr = readBuffer.reserve(available);
         NO_INTR(readBytes, read(q->masterFd(), ptr, available));
         if (readBytes < 0) {
@@ -276,12 +283,12 @@ bool KPtyDevicePrivate::_k_canRead()
 
     if (!readBytes) {
         readNotifier->setEnabled(false);
-        emit q->readEof();
+        Q_EMIT q->readEof();
         return false;
     } else {
         if (!emittedReadyRead) {
             emittedReadyRead = true;
-            emit q->readyRead();
+            Q_EMIT q->readyRead();
             emittedReadyRead = false;
         }
         return true;
@@ -299,9 +306,7 @@ bool KPtyDevicePrivate::_k_canWrite()
 
     qt_ignore_sigpipe();
     int wroteBytes;
-    NO_INTR(wroteBytes,
-            write(q->masterFd(),
-                  writeBuffer.readPointer(), writeBuffer.readSize()));
+    NO_INTR(wroteBytes, write(q->masterFd(), writeBuffer.readPointer(), writeBuffer.readSize()));
     if (wroteBytes < 0) {
         q->setErrorString(i18n("Error writing to PTY"));
         return false;
@@ -310,7 +315,7 @@ bool KPtyDevicePrivate::_k_canWrite()
 
     if (!emittedBytesWritten) {
         emittedBytesWritten = true;
-        emit q->bytesWritten(wroteBytes);
+        Q_EMIT q->bytesWritten(wroteBytes);
         emittedBytesWritten = false;
     }
 
@@ -322,7 +327,8 @@ bool KPtyDevicePrivate::_k_canWrite()
 
 #ifndef timeradd
 // Lifted from GLIBC
-# define timeradd(a, b, result) \
+/* clang-format off */
+#define timeradd(a, b, result) \
     do { \
         (result)->tv_sec = (a)->tv_sec + (b)->tv_sec; \
         (result)->tv_usec = (a)->tv_usec + (b)->tv_usec; \
@@ -331,7 +337,8 @@ bool KPtyDevicePrivate::_k_canWrite()
             (result)->tv_usec -= 1000000; \
         } \
     } while (0)
-# define timersub(a, b, result) \
+
+#define timersub(a, b, result) \
     do { \
         (result)->tv_sec = (a)->tv_sec - (b)->tv_sec; \
         (result)->tv_usec = (a)->tv_usec - (b)->tv_usec; \
@@ -341,6 +348,7 @@ bool KPtyDevicePrivate::_k_canWrite()
         } \
     } while (0)
 #endif
+/* clang-format on */
 
 bool KPtyDevicePrivate::doWait(int msecs, bool reading)
 {
@@ -432,9 +440,9 @@ void KPtyDevicePrivate::finishOpen(QIODevice::OpenMode mode)
 // public member functions //
 /////////////////////////////
 
-KPtyDevice::KPtyDevice(QObject *parent) :
-    QIODevice(parent),
-    KPty(new KPtyDevicePrivate(this))
+KPtyDevice::KPtyDevice(QObject *parent)
+    : QIODevice(parent)
+    , KPty(new KPtyDevicePrivate(this))
 {
 }
 
